==> haskell-bytestring-strict-builder-0.4.5.3-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bytestring-strict-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bytestring-strict-builder
version: 0.4.5.3
id: bytestring-strict-builder-0.4.5.3-FFrNtiWRsRxJJYdloi3RFy
key: bytestring-strict-builder-0.4.5.3-FFrNtiWRsRxJJYdloi3RFy
license: MIT
copyright: (c) 2017, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/bytestring-strict-builder
synopsis: An efficient strict bytestring builder
description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the competition benchmarks>,
    this library provides on average the fastest builder of strict bytestrings.
    .
    Practical benchmarks have proven it to be highly performant as well.
    The encoders from the \"postgresql-binary\" library have shown
    a stable performance improvement by factors of up to 10 after the migration
    from the standard builder to \"bytestring-strict-builder\".
category: Text, ByteString, Builders, Serialization
abi: e00911b528d79b5a64ab22e24421a79f
exposed: True
exposed-modules:
    ByteString.StrictBuilder
hidden-modules: ByteString.StrictBuilder.Prelude
                ByteString.StrictBuilder.Population
                ByteString.StrictBuilder.Population.UncheckedShifting
                ByteString.StrictBuilder.UTF8
import-dirs: /usr/lib/ghc-8.6.5/site-local/bytestring-strict-builder-0.4.5.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/bytestring-strict-builder-0.4.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/bytestring-strict-builder-0.4.5.3
hs-libraries: HSbytestring-strict-builder-0.4.5.3-FFrNtiWRsRxJJYdloi3RFy
depends:
    base-4.12.0.0 base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-bytestring-strict-builder/html/bytestring-strict-builder.haddock
haddock-html: /usr/share/doc/haskell-bytestring-strict-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-strict-builder-0.4.5.3-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bytestring-strict-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bytestring-strict-builder
version: 0.4.5.3
id: bytestring-strict-builder-0.4.5.3-HoaVSnZ4st1C8Lj91dUWcO
key: bytestring-strict-builder-0.4.5.3-HoaVSnZ4st1C8Lj91dUWcO
license: MIT
copyright: (c) 2017, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/bytestring-strict-builder
synopsis: An efficient strict bytestring builder
description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the competition benchmarks>,
    this library provides on average the fastest builder of strict bytestrings.
    .
    Practical benchmarks have proven it to be highly performant as well.
    The encoders from the \"postgresql-binary\" library have shown
    a stable performance improvement by factors of up to 10 after the migration
    from the standard builder to \"bytestring-strict-builder\".
category: Text, ByteString, Builders, Serialization
abi: 3b63208f4091e74b2e330b6f794ee9c0
exposed: True
exposed-modules:
    ByteString.StrictBuilder
hidden-modules: ByteString.StrictBuilder.Prelude
                ByteString.StrictBuilder.Population
                ByteString.StrictBuilder.Population.UncheckedShifting
                ByteString.StrictBuilder.UTF8
import-dirs: /usr/lib/ghc-8.6.5/site-local/bytestring-strict-builder-0.4.5.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/bytestring-strict-builder-0.4.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/bytestring-strict-builder-0.4.5.3
hs-libraries: HSbytestring-strict-builder-0.4.5.3-HoaVSnZ4st1C8Lj91dUWcO
depends:
    base-4.12.0.0 base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-bytestring-strict-builder/html/bytestring-strict-builder.haddock
haddock-html: /usr/share/doc/haskell-bytestring-strict-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
